@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.3.1'; # VERSION
+our $VERSION = 'v0.3.2'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -14,7 +14,7 @@ with qw(
 );
 
 use MooseX::StrictConstructor;
-use MooseX::Types::Moose qw( Str Int );
+use MooseX::Types::Moose qw( Str Int Bool );
 use MooseX::Types::CyberSource qw( Decision );
 use MooseX::Types::Varchar qw( Varchar );
 
@@ -53,9 +53,22 @@ has request_token => (
 		. 'reply. The field is an encoded string that contains no '
 		. 'confidential information, such as an account or card verification '
 		. 'number. The string can contain up to 256 characters.',
-
 );
 
+has is_success => (
+	required => 0,
+	lazy     => 1,
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {
+		my $self = shift;
+		return $self->decision eq 'ACCEPT' ? 1 : 0;
+	},
+	documentation => 'boolean way of determining whether the transaction was '
+		. 'a success',
+);
+
+
 sub _build_reason_text {
 	my $self = shift;
 
@@ -156,7 +169,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version v0.3.1
+version v0.3.2
 
 =head1 DESCRIPTION
 
@@ -175,6 +188,14 @@ Role|Business::CyberSource::Response::Role::Accept>
 
 =head1 ATTRIBUTES
 
+=head2 is_success
+
+Reader: is_success
+
+Type: Bool
+
+Additional documentation: boolean way of determining whether the transaction was a success
+
 =head2 reason_text
 
 Reader: reason_text
